netapp_ontap.models.zapp_s3_bucket_application_components API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.zapp_s3_bucket_application_components`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ZappS3BucketApplicationComponentsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ZappS3BucketApplicationComponents object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `access_policies: List[ZappS3BucketApplicationComponentsAccessPolicies] GET POST`

    The list of S3 objectstore policies to be created.

  `bucket_endpoint_type: str GET POST`

    The type of bucket.

    Valid choices:

    - nas
    - s3
  `capacity_tier: bool GET POST`

    Prefer lower latency storage under similar media costs.

  `comment: str GET POST`

    Object Store Server Bucket Description Usage: <(size 1..256)>

  `default_retention_period: str GET POST`

    Specifies the default retention period that is applied to objects while committing them to the WORM state without an associated retention period. The retention period can be in years, or days. The retention period value represents a duration and must be specified in the ISO-8601 duration format. A period specified for years and days is represented in the ISO-8601 format as quot;Plt;num>Y" and quot;Plt;num>D" respectively, for example "P10Y" represents a duration of 10 years. The period string must contain only a single time element that is, either years, or days. A duration which combines different periods is not supported, for example "P1Y10D" is not supported. Usage: {{<integer> days|years} | none}

  `exclude_aggregates: List[NasExcludeAggregates] GET POST`

    The exclude_aggregates field of the zapp_s3_bucket_application_components.

  `name: str GET POST PATCH`

    The name of the application component.

  `nas_path: str GET POST`

    The path to which the bucket corresponds to.

  `qos: NasApplicationComponentsQos GET POST`

    The qos field of the zapp_s3_bucket_application_components.

  `retention_mode: str GET POST`

    The lock mode of the bucket. <br>compliance ‐ A SnapLock Compliance (SLC) bucket provides the highest level of WORM protection and an administrator cannot destroy a compliance bucket if it contains unexpired WORM objects. <br> governance ‐ An administrator can delete a Governance bucket.<br> no_lock ‐ Indicates the bucket does not support object locking. For s3 type buckets, the default value is no_lock.

    Valid choices:

    - compliance
    - governance
    - no_lock
  `size: Size GET POST PATCH`

    The total size of the S3 Bucket, split across the member components. Usage: {<integer>[KB|MB|GB|TB|PB]}

  `snapshot_policy: ZappS3BucketApplicationComponentsSnapshotPolicy GET POST`

    The snapshot_policy field of the zapp_s3_bucket_application_components.

  `storage_service: NasApplicationComponentsStorageService GET POST PATCH`

    The storage_service field of the zapp_s3_bucket_application_components.

  `uuid: str GET`

    Object Store Server Bucket UUID Usage: <UUID>

  `versioning_state: str GET POST`

    Bucket Versioning State. For nas type buckets, this field is not set. For s3 type buckets, the default value is disabled.

    Valid choices:

    - disabled
    - enabled
    - suspended